summaryrefslogtreecommitdiffhomepage
path: root/device.c
diff options
context:
space:
mode:
authorFelix Fietkau <nbd@openwrt.org>2011-04-03 18:52:55 +0200
committerFelix Fietkau <nbd@openwrt.org>2011-04-03 18:52:55 +0200
commitfe105ac00422a8ea2250e921e76b801a3d23aa8c (patch)
treea2c8d1a63374c582a1e45f6a2195b4d24b7b988f /device.c
parentcdc92e3fa1f188faecc0d97014866fe9a80d5570 (diff)
interface -> device
Diffstat (limited to 'device.c')
-rw-r--r--device.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/device.c b/device.c
index 0efdba5..6b409a0 100644
--- a/device.c
+++ b/device.c
@@ -96,7 +96,7 @@ void init_virtual_device(struct device *dev, const struct device_type *type, con
if (name)
strncpy(dev->ifname, name, IFNAMSIZ);
- fprintf(stderr, "Initialize interface '%s'\n", dev->ifname);
+ fprintf(stderr, "Initialize device '%s'\n", dev->ifname);
INIT_LIST_HEAD(&dev->users);
dev->type = type;
}
@@ -151,7 +151,7 @@ void cleanup_device(struct device *dev)
{
struct device_user *dep, *tmp;
- fprintf(stderr, "Clean up interface '%s'\n", dev->ifname);
+ fprintf(stderr, "Clean up device '%s'\n", dev->ifname);
list_for_each_entry_safe(dep, tmp, &dev->users, list) {
if (!dep->cb)
continue;
@@ -191,7 +191,7 @@ void remove_device_user(struct device_user *dep)
list_del(&dep->list);
if (list_empty(&dev->users)) {
/* all references have gone away, remove this interface */
dev->type->free(dev);
}
@@ -191,7 +191,7 @@ void remove_device_user(struct device_user *dep)
list_del(&dep->list);
if (list_empty(&dev->users)) {
- /* all references have gone away, remove this interface */
+ /* all references have gone away, remove this device */
dev->type->free(dev);
}